@@ -2,16 +2,18 @@ import csv
 import numpy as np
 import utm
 
+MPH_TO_MS = 0.44704
+FT_TO_M = 0.3048
 
 KEYS = (
     'latitude',
     'longitude',
-    ('time(millisecond)','t_ms',int,1),
-    ('height_above_takeoff(feet)','height_above_TO_m',float,0.3048),
-    ('speed(mph)','speed_ms',float,0.44704),
-    (' xSpeed(mph)','x_speed_ms',float,0.44704),    
-    (' ySpeed(mph)','y_speed_ms',float,0.44704),
-    (' zSpeed(mph)','z_speed_ms',float,0.44704)    
+    ('time(millisecond)','t_s',float,0.001),
+    ('height_above_takeoff(feet)','height_above_TO_m',float,FT_TO_M),
+    ('speed(mph)','speed_ms',float,MPH_TO_MS),
+    (' xSpeed(mph)','x_speed_ms',float,MPH_TO_MS),    
+    (' ySpeed(mph)','y_speed_ms',float,MPH_TO_MS),
+    (' zSpeed(mph)','z_speed_ms',float,MPH_TO_MS)    
     )
 
 
@@ -40,10 +42,14 @@ class UAVData:
 
     def _latlng_to_local(self):
         xy = utm.from_latlon(np.array(self.latitude),np.array(self.longitude))
-        print(xy)
-        self.x = np.copy(xy[0]-xy[0][0])
-        self.y = np.copy(xy[1]-xy[1][0])
+
+        self.utm_zone_number = xy[2]
+        self.utm_zone_letter = xy[3]
+        self.utm = np.copy([xy[0],xy[1]])
+
 
 
 if __name__ == "__main__":
-    a = UAVData('/home/jhewers/Documents/meng_project/ps_data/2020-11-19_14-18-29.csv')    
\ No newline at end of file
+    a = UAVData('/home/jhewers/Documents/meng_project/ps_data/2020-11-19_14-18-29.csv')  
+    
+    print(a.utm.shape)
\ No newline at end of file
